/***************************************************************
 ************************* A TPP Project ***********************
 ******************** Visit http://tpp.dhs.org *****************
 ***************************************************************
dstring.h

Author(s): Paul Fleischer (polle@denmark.crosswinds.net)
Created: 18. July 1999

Copyright(c) 1999 The AKOS team.
All Rights Reserved.
****************************************************************/

/*
This is the dynamic string(dstring) class.
It makes sure that the string never allocates more memory than it uses, and
it automatically expands the allocated memory when necesarry
 */

#ifndef DSTRING_H
#define DSTRING_H

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

class dstring
{
 public:
  dstring(char *stdvalue = 0);
  ~dstring();

  //Assignment operators
  void operator =(char *string);
  void operator =(int i);
  void operator =(double f);
  void operator =(dstring ds); //NOT WORKING, use dstring1 = dstring2.tochar() instead

  //Plus assignment operators
  void operator +=(char *string);
  void operator +=(int i);
  void operator +=(double f);
  void operator +=(char c);
 
  //Output conversion
  char *tochar();
  int toint();
  double todouble();

 private:
  //Internal data functions
  char *data;
  unsigned int size;
  bool isalloc;

  //Data (de)allocation functions, size must be set before these calls
  //It's secure to call alloc() without dealloc(), since alloc automatically
  //does it.
  void dealloc();
  void alloc();

  //Internal functions used by the assignment operators
  void itos(int i);
  void ftos(double f);
};

class darray
{
 public:
  darray(void);
  ~darray();
  void setItem(unsigned int item, dstring *newItem);
  dstring *getItem(unsigned int item);
  void delItem(unsigned int item);
  unsigned int getSize(void);

 private:
  void resize(unsigned int newSize);

  unsigned int noOfItems;
  dstring **items;
};

#endif



